#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 persistent
version:              2.13.0.2
visibility:           public
id:                   persistent-2.13.0.2-La3E9BZccdVB7xnmOANUxr
key:                  persistent-2.13.0.2-La3E9BZccdVB7xnmOANUxr
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/persistent
synopsis:             Type-safe, multi-backend data serialization.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent>.

category:             Database, Yesod
abi:                  8183f386d293aa51c77063da6664442e
exposed:              True
exposed-modules:
    Database.Persist Database.Persist.Class
    Database.Persist.Class.DeleteCascade
    Database.Persist.Class.PersistConfig
    Database.Persist.Class.PersistEntity
    Database.Persist.Class.PersistField
    Database.Persist.Class.PersistQuery
    Database.Persist.Class.PersistStore
    Database.Persist.Class.PersistUnique Database.Persist.Compatible
    Database.Persist.EntityDef Database.Persist.EntityDef.Internal
    Database.Persist.FieldDef Database.Persist.FieldDef.Internal
    Database.Persist.ImplicitIdDef
    Database.Persist.ImplicitIdDef.Internal Database.Persist.Names
    Database.Persist.PersistValue Database.Persist.Quasi
    Database.Persist.Quasi.Internal Database.Persist.Sql
    Database.Persist.Sql.Types.Internal Database.Persist.Sql.Util
    Database.Persist.SqlBackend Database.Persist.SqlBackend.Internal
    Database.Persist.SqlBackend.Internal.InsertSqlResult
    Database.Persist.SqlBackend.Internal.IsolationLevel
    Database.Persist.SqlBackend.Internal.MkSqlBackend
    Database.Persist.SqlBackend.Internal.Statement Database.Persist.TH
    Database.Persist.Types

hidden-modules:
    Database.Persist.Types.Base Database.Persist.Sql.Migration
    Database.Persist.Sql.Internal Database.Persist.Sql.Types
    Database.Persist.Sql.Raw Database.Persist.Sql.Run
    Database.Persist.Sql.Class Database.Persist.Sql.Orphan.PersistQuery
    Database.Persist.Sql.Orphan.PersistStore
    Database.Persist.Sql.Orphan.PersistUnique
    Database.Persist.Compatible.Types Database.Persist.Compatible.TH

import-dirs:          /usr/lib/ghc-8.10.5/site-local/persistent-2.13.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/persistent-2.13.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/persistent-2.13.0.2
hs-libraries:         HSpersistent-2.13.0.2-La3E9BZccdVB7xnmOANUxr
depends:
    aeson-1.5.6.0-CVfeYccFVpdCde0UrZZZdZ
    attoparsec-0.14.1-CDW2c9fsk3y4jVQKNBcpib base-4.14.2.0
    base64-bytestring-1.2.0.1-9folcSD81CwJ7ibR6pZE7R
    blaze-html-0.9.1.2-3gWJOEFN3Rn7Mv2jAJdKwl bytestring-0.10.12.0
    conduit-1.3.4.1-GHgRKpknFuqDscwzVojbiE containers-0.6.4.1
    fast-logger-3.0.5-I5dfCGxOK271HLzqt5yeow
    http-api-data-0.4.3-JUnrChvmGZhIDkVtiYRrjz
    lift-type-0.1.0.1-BP9jBiYHoW21ZiG8vrxFr
    monad-logger-0.3.36-1GrKwR43Dhh83kQQb62BZS mtl-2.2.2
    path-pieces-0.2.1-5gT7wFDsgDLEW6f8EG31Nu
    resource-pool-0.2.3.2-HuMDXx2LvNiFKUxNwBNmWZ
    resourcet-1.2.4.2-7etOfd8fePh2l91avxjTIe
    scientific-0.3.7.0-Fi0gRGhsiJ35wgbCjOXuHX
    silently-1.2.5.1-5AY3YtA0BMv8o5E54Ijg9F template-haskell-2.16.0.0
    text-1.2.4.1 th-lift-instances-0.1.18-ISzSdEYjwO2HcQG406Y9jF
    time-1.9.3 transformers-0.5.6.2
    unliftio-0.2.18-5P4UivtPmWZvk4Y5NpZt0
    unliftio-core-0.2.0.1-1ibY1oF6Hkc5ZYjZ4yW3Lp
    unordered-containers-0.2.14.0-JpdjDmlqBJN4PAu3jIj4Ya
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-persistent/html/persistent.haddock
haddock-html:         /usr/share/doc/haskell-persistent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

